﻿Copyright (c) 2020 Fluke Calibration                        MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Get Accuracy (base units) /HFSG
DATE:                  2022-02-18 09:05:31
AUTHOR:                Fluke
REVISION:              $Revision: 31688 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       92
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
  1.002  IEEE         [@HFSG]
  1.003  ENDIF

# -----  Cardinal Point: Frequency  ---------------
  1.004  IF           ZCMPI(@HFSG_CPT, "Freq")
# Specify Nominal value of parameter.
  1.005  MATH         @HFSG_Nominal = @HFSG_Freq
# Specify third and fourth ACCV2 arguments (frequency and amplitude).
  1.006  MATH         FreqBase = BASE(@HFSG_Freq)
  1.007  MATH         AmplBase = BASE(@HFSG_Ampl)
# Specify HFSG frequency mode string in ModeStr from ini file.
  1.008  MATH         ModeStr = RINFE(@HFSG_DevName, "ModeStringFreq")

# Check for option that affects accuracy.
  1.009  IF           NOT(EMPTY(@HFSG_FreqOpt))
# Append option to mode string.
  1.010  MATH         ModeStr = ModeStr & " " & @HFSG_FreqOpt
  1.011  ENDIF        ; Options

# Retrieve HFSG frequency accuracy.
  1.012  MATH         Acc = ACCV2(@HFSG_DevName, ModeStr, FreqBase, AmplBase)

# -----  Cardinal Point: Amplitude  ---------------
  1.013  ELSEIF       ZCMPI(@HFSG_CPT, "Ampl")
  1.014  MATH         @HFSG_Nominal = @HFSG_Ampl
  1.015  MATH         FreqBase = BASE(@HFSG_Freq)
  1.016  MATH         AmplBase = BASE(@HFSG_Ampl)
  1.017  MATH         ModeStr = RINFE(@HFSG_DevName, "ModeStringAmpl")

  1.018  IF           NOT(EMPTY(@HFSG_AmplOpt))
  1.019  MATH         ModeStr = ModeStr & " " & @HFSG_AmplOpt
  1.020  ENDIF        ; Options

  1.021  MATH         Acc = ACCV2(@HFSG_DevName, ModeStr, AmplBase, FreqBase)

# -----  Cardinal Point: Flatness  ----------------
  1.022  ELSEIF       ZCMPI(@HFSG_CPT, "Flat")

  1.023  MATH         @HFSG_Nominal = @HFSG_Ampl
  1.024  MATH         FreqBase = BASE(@HFSG_Freq)
  1.025  MATH         AmplBase = BASE(@HFSG_Ampl)
  1.026  MATH         ModeStr = RINFE(@HFSG_DevName, "ModeStringFlat")

  1.027  IF           NOT(EMPTY(@HFSG_AmplOpt))
  1.028  MATH         ModeStr = ModeStr & " " & @HFSG_AmplOpt
  1.029  ENDIF        ; Options

  1.030  MATH         Acc = ACCV2(@HFSG_DevName, ModeStr, AmplBase, FreqBase)

  1.031  ENDIF        ; Cardinal point parameters.

# Get value of VSET parameter, confidence value.
  1.032  MATH         Confidence = VGET("CONF")

# VGET query returns empty string if CONF is set to default (2).
  1.033  IF           EMPTY(Confidence)
  1.034  MATH         Confidence = 2
  1.035  ENDIF

  1.036  MATH         @HFSG_Acc = (Acc / CONF(@HFSG_DevName)) * Confidence

  1.037  END
